import { PrismaClient } from "@prisma/client";

const prisma = new PrismaClient();

export const getEvents = async (req, res) => {
    try {
        const events = await prisma.events.findMany();
        res.status(200).json({ status: 200, data: events });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
};

export const createEvent = async (req, res) => {
    const { title, description, date } = req.body;
    try {
        const newEvent = await prisma.events.create({
            data: {
                title,
                description,
                date,
            },
        });
        res.status(201).json({ status: 201, data: newEvent });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
};

export const updateEvent = async (req, res) => {
    const { id } = req.params;
    try {
        const updatedEvent = await prisma.events.update({
            where: { id: id },
            data: {
                ...req?.body,
            },
        });
        res.status(200).json({ status: 200, data: updatedEvent });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
};

export const deleteEvent = async (req, res) => {
    const { id } = req.params;
    try {
        await prisma.events.delete({
            where: { id: id },
        });
        res.status(200).json({
            status: 200,
            message: "Event deleted successfully",
        });
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
};
